pynrc.DetectorOps
=================

.. currentmodule:: pynrc

.. autoclass:: DetectorOps
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~DetectorOps.channel
      ~DetectorOps.chsize
      ~DetectorOps.detid
      ~DetectorOps.detid_list
      ~DetectorOps.detname
      ~DetectorOps.module
      ~DetectorOps.nff
      ~DetectorOps.nout
      ~DetectorOps.ref_info
      ~DetectorOps.scaid
      ~DetectorOps.scaid_list
      ~DetectorOps.time_exp
      ~DetectorOps.time_frame
      ~DetectorOps.time_group
      ~DetectorOps.time_int
      ~DetectorOps.time_ramp
      ~DetectorOps.time_row_reset
      ~DetectorOps.time_total
      ~DetectorOps.time_total_int

   .. rubric:: Methods Summary

   .. autosummary::

      ~DetectorOps.make_header
      ~DetectorOps.pixel_noise
      ~DetectorOps.pixel_timing_map
      ~DetectorOps.times_to_dict
      ~DetectorOps.to_dict

   .. rubric:: Methods Documentation

   .. automethod:: make_header
   .. automethod:: pixel_noise
   .. automethod:: pixel_timing_map
   .. automethod:: times_to_dict
   .. automethod:: to_dict
